"""Constants.
"""

# A constant value used to avoid division by zero, zero logarithms
# and any possible mathematical error
EPSILON = 1e-10
